@@ -42,6 +42,19 @@ def test_version_parts_compare():
     assert res
 
 
+def test_version_build_compare():
+    res = utils.version_compare("1.2.0", "1.2.0-alpha", "1.2.0-beta")
+    assert not res
+    res = utils.version_compare("1.2.0", "1.1.0-alpha", "1.2.0-beta")
+    assert not res
+    res = utils.version_compare("1.3.0", "1.2.0-alpha", "1.3.1-beta")
+    assert res
+    res = utils.version_compare("1.3.0", "1.2.0", "1.3.1-beta")
+    assert res
+    res = utils.version_compare("1.3.0", "1.2.0-beta", "1.3.2.0")
+    assert res
+
+
 def test_parse_uri():
     vendor, package, version = utils.parse_cpe(
         "cpe:2.3:o:google:android:9.0:*:*:*:*:*:*:*"
